@@ -8,6 +8,11 @@ exports["Africa/El_Aaiun"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Africa/El_Aaiun", { abbr: true, expect: "Africa/Casablanca" }),
 
+	"1934" : helpers.makeTestYear("Africa/El_Aaiun", [
+		["1934-01-01T00:52:47+00:00", "23:59:59", "LMT", 3168 / 60],
+		["1934-01-01T00:52:48+00:00", "23:52:48", "-01", 60]
+	]),
+
 	"1976" : helpers.makeTestYear("Africa/El_Aaiun", [
 		["1976-04-14T00:59:59+00:00", "23:59:59", "-01", 60],
 		["1976-04-14T01:00:00+00:00", "01:00:00", "+00", 0],
@@ -268,6 +273,8 @@ exports["Africa/El_Aaiun"] = {
 
 	"2037" : helpers.makeTestYear("Africa/El_Aaiun", [
 		["2037-10-04T01:59:59+00:00", "02:59:59", "+01", -60],
-		["2037-10-04T02:00:00+00:00", "02:00:00", "+00", 0]
+		["2037-10-04T02:00:00+00:00", "02:00:00", "+00", 0],
+		["2037-11-15T01:59:59+00:00", "01:59:59", "+00", 0],
+		["2037-11-15T02:00:00+00:00", "03:00:00", "+01", -60]
 	])
 };
\ No newline at end of file
