@@ -23,5 +23,10 @@ exports["Africa/Johannesburg"] = {
 		["1943-03-20T23:00:00+00:00", "01:00:00", "SAST", -120],
 		["1943-09-18T23:59:59+00:00", "01:59:59", "SAST", -120],
 		["1943-09-19T00:00:00+00:00", "03:00:00", "SAST", -180]
+	]),
+
+	"1944" : helpers.makeTestYear("Africa/Johannesburg", [
+		["1944-03-18T22:59:59+00:00", "01:59:59", "SAST", -180],
+		["1944-03-18T23:00:00+00:00", "01:00:00", "SAST", -120]
 	])
 };
\ No newline at end of file
