@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["America/Adak"] = {
-	"guess" : helpers.makeTestGuess("America/Adak", { offset: true, abbr: true }),
+
+	"guess:by:offset" : helpers.makeTestGuess("America/Adak", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("America/Adak", { abbr: true }),
 
 	"1942" : helpers.makeTestYear("America/Adak", [
 		["1942-02-09T12:59:59+00:00", "01:59:59", "NST", 660],
