@@ -223,5 +223,10 @@ exports["America/Argentina/Cordoba"] = {
 		["2008-03-16T02:00:00+00:00", "23:00:00", "-03", 180],
 		["2008-10-19T02:59:59+00:00", "23:59:59", "-03", 180],
 		["2008-10-19T03:00:00+00:00", "01:00:00", "-02", 120]
+	]),
+
+	"2009" : helpers.makeTestYear("America/Argentina/Cordoba", [
+		["2009-03-15T01:59:59+00:00", "23:59:59", "-02", 120],
+		["2009-03-15T02:00:00+00:00", "23:00:00", "-03", 180]
 	])
 };
\ No newline at end of file
