@@ -8,6 +8,11 @@ exports["America/Barbados"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Barbados", { abbr: true, expect: "America/Santo_Domingo" }),
 
+	"1924" : helpers.makeTestYear("America/Barbados", [
+		["1924-01-01T03:58:28+00:00", "23:59:59", "LMT", 14309 / 60],
+		["1924-01-01T03:58:29+00:00", "00:00:00", "BMT", 14309 / 60]
+	]),
+
 	"1932" : helpers.makeTestYear("America/Barbados", [
 		["1932-01-01T03:58:28+00:00", "23:59:59", "BMT", 14309 / 60],
 		["1932-01-01T03:58:29+00:00", "23:58:29", "AST", 240]
@@ -36,6 +41,8 @@ exports["America/Barbados"] = {
 
 	"1980" : helpers.makeTestYear("America/Barbados", [
 		["1980-04-20T05:59:59+00:00", "01:59:59", "AST", 240],
-		["1980-04-20T06:00:00+00:00", "03:00:00", "ADT", 180]
+		["1980-04-20T06:00:00+00:00", "03:00:00", "ADT", 180],
+		["1980-09-25T04:59:59+00:00", "01:59:59", "ADT", 180],
+		["1980-09-25T05:00:00+00:00", "01:00:00", "AST", 240]
 	])
 };
\ No newline at end of file
