@@ -16,5 +16,10 @@ exports["America/Bogota"] = {
 	"1992" : helpers.makeTestYear("America/Bogota", [
 		["1992-05-03T04:59:59+00:00", "23:59:59", "-05", 300],
 		["1992-05-03T05:00:00+00:00", "01:00:00", "-04", 240]
+	]),
+
+	"1993" : helpers.makeTestYear("America/Bogota", [
+		["1993-04-04T03:59:59+00:00", "23:59:59", "-04", 240],
+		["1993-04-04T04:00:00+00:00", "23:00:00", "-05", 300]
 	])
 };
\ No newline at end of file
