@@ -8,6 +8,11 @@ exports["America/Cancun"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Cancun", { abbr: true, expect: "America/Panama" }),
 
+	"1922" : helpers.makeTestYear("America/Cancun", [
+		["1922-01-01T05:59:59+00:00", "00:12:55", "LMT", 20824 / 60],
+		["1922-01-01T06:00:00+00:00", "00:00:00", "CST", 360]
+	]),
+
 	"1981" : helpers.makeTestYear("America/Cancun", [
 		["1981-12-23T05:59:59+00:00", "23:59:59", "CST", 360],
 		["1981-12-23T06:00:00+00:00", "01:00:00", "EST", 300]
@@ -146,5 +151,10 @@ exports["America/Cancun"] = {
 		["2014-04-06T08:00:00+00:00", "03:00:00", "CDT", 300],
 		["2014-10-26T06:59:59+00:00", "01:59:59", "CDT", 300],
 		["2014-10-26T07:00:00+00:00", "01:00:00", "CST", 360]
+	]),
+
+	"2015" : helpers.makeTestYear("America/Cancun", [
+		["2015-02-01T07:59:59+00:00", "01:59:59", "CST", 360],
+		["2015-02-01T08:00:00+00:00", "03:00:00", "EST", 300]
 	])
 };
\ No newline at end of file
