@@ -21,5 +21,10 @@ exports["America/Caracas"] = {
 	"2007" : helpers.makeTestYear("America/Caracas", [
 		["2007-12-09T06:59:59+00:00", "02:59:59", "-04", 240],
 		["2007-12-09T07:00:00+00:00", "02:30:00", "-0430", 270]
+	]),
+
+	"2016" : helpers.makeTestYear("America/Caracas", [
+		["2016-05-01T06:59:59+00:00", "02:29:59", "-0430", 270],
+		["2016-05-01T07:00:00+00:00", "03:00:00", "-04", 240]
 	])
 };
\ No newline at end of file
