@@ -27,6 +27,8 @@ exports["America/Coral_Harbour"] = {
 
 	"1945" : helpers.makeTestYear("America/Coral_Harbour", [
 		["1945-08-14T22:59:59+00:00", "17:59:59", "CWT", 300],
-		["1945-08-14T23:00:00+00:00", "18:00:00", "CPT", 300]
+		["1945-08-14T23:00:00+00:00", "18:00:00", "CPT", 300],
+		["1945-09-30T06:59:59+00:00", "01:59:59", "CPT", 300],
+		["1945-09-30T07:00:00+00:00", "02:00:00", "EST", 300]
 	])
 };
\ No newline at end of file
