@@ -501,5 +501,10 @@ exports["America/Fort_Nelson"] = {
 		["2014-03-09T10:00:00+00:00", "03:00:00", "PDT", 420],
 		["2014-11-02T08:59:59+00:00", "01:59:59", "PDT", 420],
 		["2014-11-02T09:00:00+00:00", "01:00:00", "PST", 480]
+	]),
+
+	"2015" : helpers.makeTestYear("America/Fort_Nelson", [
+		["2015-03-08T09:59:59+00:00", "01:59:59", "PST", 480],
+		["2015-03-08T10:00:00+00:00", "03:00:00", "MST", 420]
 	])
 };
\ No newline at end of file
