@@ -49,18 +49,15 @@ exports["America/Kentucky/Louisville"] = {
 	]),
 
 	"1946" : helpers.makeTestYear("America/Kentucky/Louisville", [
-		["1946-01-01T05:59:59+00:00", "23:59:59", "CST", 360],
-		["1946-01-01T06:00:00+00:00", "01:00:00", "CDT", 300],
+		["1946-04-28T06:00:59+00:00", "00:00:59", "CST", 360],
+		["1946-04-28T06:01:00+00:00", "01:01:00", "CDT", 300],
 		["1946-06-02T06:59:59+00:00", "01:59:59", "CDT", 300],
 		["1946-06-02T07:00:00+00:00", "01:00:00", "CST", 360]
 	]),
 
-	"1947" : helpers.makeTestYear("America/Kentucky/Louisville", [
-		["1947-04-27T07:59:59+00:00", "01:59:59", "CST", 360],
-		["1947-04-27T08:00:00+00:00", "03:00:00", "CDT", 300]
-	]),
-
 	"1950" : helpers.makeTestYear("America/Kentucky/Louisville", [
+		["1950-04-30T07:59:59+00:00", "01:59:59", "CST", 360],
+		["1950-04-30T08:00:00+00:00", "03:00:00", "CDT", 300],
 		["1950-09-24T06:59:59+00:00", "01:59:59", "CDT", 300],
 		["1950-09-24T07:00:00+00:00", "01:00:00", "CST", 360]
 	]),
