@@ -63,6 +63,8 @@ exports["America/Managua"] = {
 
 	"2006" : helpers.makeTestYear("America/Managua", [
 		["2006-04-30T07:59:59+00:00", "01:59:59", "CST", 360],
-		["2006-04-30T08:00:00+00:00", "03:00:00", "CDT", 300]
+		["2006-04-30T08:00:00+00:00", "03:00:00", "CDT", 300],
+		["2006-10-01T05:59:59+00:00", "00:59:59", "CDT", 300],
+		["2006-10-01T06:00:00+00:00", "00:00:00", "CST", 360]
 	])
 };
\ No newline at end of file
