@@ -15,6 +15,8 @@ exports["America/Martinique"] = {
 
 	"1980" : helpers.makeTestYear("America/Martinique", [
 		["1980-04-06T03:59:59+00:00", "23:59:59", "AST", 240],
-		["1980-04-06T04:00:00+00:00", "01:00:00", "ADT", 180]
+		["1980-04-06T04:00:00+00:00", "01:00:00", "ADT", 180],
+		["1980-09-28T02:59:59+00:00", "23:59:59", "ADT", 180],
+		["1980-09-28T03:00:00+00:00", "23:00:00", "AST", 240]
 	])
 };
\ No newline at end of file
