@@ -15,6 +15,8 @@ exports["America/Puerto_Rico"] = {
 
 	"1945" : helpers.makeTestYear("America/Puerto_Rico", [
 		["1945-08-14T22:59:59+00:00", "19:59:59", "AWT", 180],
-		["1945-08-14T23:00:00+00:00", "20:00:00", "APT", 180]
+		["1945-08-14T23:00:00+00:00", "20:00:00", "APT", 180],
+		["1945-09-30T04:59:59+00:00", "01:59:59", "APT", 180],
+		["1945-09-30T05:00:00+00:00", "01:00:00", "AST", 240]
 	])
 };
\ No newline at end of file
