@@ -8,6 +8,11 @@ exports["America/Regina"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("America/Regina", { abbr: true, expect: "America/Managua" }),
 
+	"1905" : helpers.makeTestYear("America/Regina", [
+		["1905-09-01T06:58:35+00:00", "23:59:59", "LMT", 25116 / 60],
+		["1905-09-01T06:58:36+00:00", "23:58:36", "MST", 420]
+	]),
+
 	"1918" : helpers.makeTestYear("America/Regina", [
 		["1918-04-14T08:59:59+00:00", "01:59:59", "MST", 420],
 		["1918-04-14T09:00:00+00:00", "03:00:00", "MDT", 360],
@@ -186,5 +191,10 @@ exports["America/Regina"] = {
 		["1959-04-26T09:00:00+00:00", "03:00:00", "MDT", 360],
 		["1959-10-25T07:59:59+00:00", "01:59:59", "MDT", 360],
 		["1959-10-25T08:00:00+00:00", "01:00:00", "MST", 420]
+	]),
+
+	"1960" : helpers.makeTestYear("America/Regina", [
+		["1960-04-24T08:59:59+00:00", "01:59:59", "MST", 420],
+		["1960-04-24T09:00:00+00:00", "03:00:00", "CST", 360]
 	])
 };
\ No newline at end of file
