@@ -8,6 +8,11 @@ exports["Asia/Almaty"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Almaty", { abbr: true, expect: "Asia/Dhaka" }),
 
+	"1924" : helpers.makeTestYear("Asia/Almaty", [
+		["1924-05-01T18:52:11+00:00", "23:59:59", "LMT", -18468 / 60],
+		["1924-05-01T18:52:12+00:00", "23:52:12", "+05", -300]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Almaty", [
 		["1930-06-20T18:59:59+00:00", "23:59:59", "+05", -300],
 		["1930-06-20T19:00:00+00:00", "01:00:00", "+06", -360]
@@ -178,6 +183,8 @@ exports["Asia/Almaty"] = {
 
 	"2004" : helpers.makeTestYear("Asia/Almaty", [
 		["2004-03-27T19:59:59+00:00", "01:59:59", "+06", -360],
-		["2004-03-27T20:00:00+00:00", "03:00:00", "+07", -420]
+		["2004-03-27T20:00:00+00:00", "03:00:00", "+07", -420],
+		["2004-10-30T19:59:59+00:00", "02:59:59", "+07", -420],
+		["2004-10-30T20:00:00+00:00", "02:00:00", "+06", -360]
 	])
 };
\ No newline at end of file
