@@ -8,6 +8,11 @@ exports["Asia/Aqtobe"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Aqtobe", { abbr: true, expect: "Asia/Karachi" }),
 
+	"1924" : helpers.makeTestYear("Asia/Aqtobe", [
+		["1924-05-01T20:11:19+00:00", "23:59:59", "LMT", -13720 / 60],
+		["1924-05-01T20:11:20+00:00", "00:11:20", "+04", -240]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Aqtobe", [
 		["1930-06-20T19:59:59+00:00", "23:59:59", "+04", -240],
 		["1930-06-20T20:00:00+00:00", "01:00:00", "+05", -300]
@@ -178,6 +183,8 @@ exports["Asia/Aqtobe"] = {
 
 	"2004" : helpers.makeTestYear("Asia/Aqtobe", [
 		["2004-03-27T20:59:59+00:00", "01:59:59", "+05", -300],
-		["2004-03-27T21:00:00+00:00", "03:00:00", "+06", -360]
+		["2004-03-27T21:00:00+00:00", "03:00:00", "+06", -360],
+		["2004-10-30T20:59:59+00:00", "02:59:59", "+06", -360],
+		["2004-10-30T21:00:00+00:00", "02:00:00", "+05", -300]
 	])
 };
\ No newline at end of file
