@@ -8,6 +8,11 @@ exports["Asia/Ashkhabad"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Ashkhabad", { abbr: true, expect: "Asia/Karachi" }),
 
+	"1924" : helpers.makeTestYear("Asia/Ashkhabad", [
+		["1924-05-01T20:06:27+00:00", "23:59:59", "LMT", -14012 / 60],
+		["1924-05-01T20:06:28+00:00", "00:06:28", "+04", -240]
+	]),
+
 	"1930" : helpers.makeTestYear("Asia/Ashkhabad", [
 		["1930-06-20T19:59:59+00:00", "23:59:59", "+04", -240],
 		["1930-06-20T20:00:00+00:00", "01:00:00", "+05", -300]
@@ -88,5 +93,10 @@ exports["Asia/Ashkhabad"] = {
 		["1991-03-30T21:00:00+00:00", "02:00:00", "+05", -300],
 		["1991-09-28T21:59:59+00:00", "02:59:59", "+05", -300],
 		["1991-09-28T22:00:00+00:00", "02:00:00", "+04", -240]
+	]),
+
+	"1992" : helpers.makeTestYear("Asia/Ashkhabad", [
+		["1992-01-18T21:59:59+00:00", "01:59:59", "+04", -240],
+		["1992-01-18T22:00:00+00:00", "03:00:00", "+05", -300]
 	])
 };
\ No newline at end of file
