@@ -137,6 +137,20 @@ exports["Asia/Gaza"] = {
 		["1975-08-30T21:00:00+00:00", "23:00:00", "IST", -120]
 	]),
 
+	"1980" : helpers.makeTestYear("Asia/Gaza", [
+		["1980-08-01T21:59:59+00:00", "23:59:59", "IST", -120],
+		["1980-08-01T22:00:00+00:00", "01:00:00", "IDT", -180],
+		["1980-09-12T21:59:59+00:00", "00:59:59", "IDT", -180],
+		["1980-09-12T22:00:00+00:00", "00:00:00", "IST", -120]
+	]),
+
+	"1984" : helpers.makeTestYear("Asia/Gaza", [
+		["1984-05-04T21:59:59+00:00", "23:59:59", "IST", -120],
+		["1984-05-04T22:00:00+00:00", "01:00:00", "IDT", -180],
+		["1984-08-24T21:59:59+00:00", "00:59:59", "IDT", -180],
+		["1984-08-24T22:00:00+00:00", "00:00:00", "IST", -120]
+	]),
+
 	"1985" : helpers.makeTestYear("Asia/Gaza", [
 		["1985-04-13T21:59:59+00:00", "23:59:59", "IST", -120],
 		["1985-04-13T22:00:00+00:00", "01:00:00", "IDT", -180],
@@ -378,134 +392,134 @@ exports["Asia/Gaza"] = {
 	]),
 
 	"2019" : helpers.makeTestYear("Asia/Gaza", [
-		["2019-03-22T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2019-03-22T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2019-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2019-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2019-10-25T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2019-10-25T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2020" : helpers.makeTestYear("Asia/Gaza", [
-		["2020-03-27T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2020-03-27T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2020-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2020-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2020-10-30T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2020-10-30T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2021" : helpers.makeTestYear("Asia/Gaza", [
-		["2021-03-26T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2021-03-26T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2021-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2021-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2021-10-29T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2021-10-29T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2022" : helpers.makeTestYear("Asia/Gaza", [
-		["2022-03-25T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2022-03-25T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2022-03-24T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2022-03-24T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2022-10-28T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2022-10-28T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2023" : helpers.makeTestYear("Asia/Gaza", [
-		["2023-03-24T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2023-03-24T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2023-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2023-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2023-10-27T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2023-10-27T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2024" : helpers.makeTestYear("Asia/Gaza", [
-		["2024-03-22T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2024-03-22T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2024-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2024-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2024-10-25T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2024-10-25T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2025" : helpers.makeTestYear("Asia/Gaza", [
-		["2025-03-21T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2025-03-21T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2025-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2025-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2025-10-24T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2025-10-24T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2026" : helpers.makeTestYear("Asia/Gaza", [
-		["2026-03-27T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2026-03-27T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2026-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2026-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2026-10-30T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2026-10-30T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2027" : helpers.makeTestYear("Asia/Gaza", [
-		["2027-03-26T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2027-03-26T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2027-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2027-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2027-10-29T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2027-10-29T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2028" : helpers.makeTestYear("Asia/Gaza", [
-		["2028-03-24T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2028-03-24T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2028-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2028-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2028-10-27T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2028-10-27T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2029" : helpers.makeTestYear("Asia/Gaza", [
-		["2029-03-23T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2029-03-23T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2029-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2029-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2029-10-26T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2029-10-26T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2030" : helpers.makeTestYear("Asia/Gaza", [
-		["2030-03-22T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2030-03-22T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2030-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2030-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2030-10-25T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2030-10-25T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2031" : helpers.makeTestYear("Asia/Gaza", [
-		["2031-03-21T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2031-03-21T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2031-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2031-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2031-10-24T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2031-10-24T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2032" : helpers.makeTestYear("Asia/Gaza", [
-		["2032-03-26T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2032-03-26T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2032-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2032-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2032-10-29T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2032-10-29T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2033" : helpers.makeTestYear("Asia/Gaza", [
-		["2033-03-25T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2033-03-25T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2033-03-24T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2033-03-24T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2033-10-28T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2033-10-28T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2034" : helpers.makeTestYear("Asia/Gaza", [
-		["2034-03-24T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2034-03-24T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2034-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2034-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2034-10-27T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2034-10-27T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2035" : helpers.makeTestYear("Asia/Gaza", [
-		["2035-03-23T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2035-03-23T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2035-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2035-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2035-10-26T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2035-10-26T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2036" : helpers.makeTestYear("Asia/Gaza", [
-		["2036-03-21T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2036-03-21T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2036-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2036-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2036-10-24T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2036-10-24T22:00:00+00:00", "00:00:00", "EET", -120]
 	]),
 
 	"2037" : helpers.makeTestYear("Asia/Gaza", [
-		["2037-03-27T22:59:59+00:00", "00:59:59", "EET", -120],
-		["2037-03-27T23:00:00+00:00", "02:00:00", "EEST", -180],
+		["2037-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
+		["2037-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
 		["2037-10-30T21:59:59+00:00", "00:59:59", "EEST", -180],
 		["2037-10-30T22:00:00+00:00", "00:00:00", "EET", -120]
 	])
