@@ -8,5 +8,8 @@ exports["Asia/Muscat"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Muscat", { abbr: true, expect: "Asia/Dubai" }),
 
-
+	"1919" : helpers.makeTestYear("Asia/Muscat", [
+		["1919-12-31T20:18:47+00:00", "23:59:59", "LMT", -13272 / 60],
+		["1919-12-31T20:18:48+00:00", "00:18:48", "+04", -240]
+	])
 };
\ No newline at end of file
