@@ -97,6 +97,8 @@ exports["Asia/Shanghai"] = {
 
 	"1991" : helpers.makeTestYear("Asia/Shanghai", [
 		["1991-04-13T17:59:59+00:00", "01:59:59", "CST", -480],
-		["1991-04-13T18:00:00+00:00", "03:00:00", "CDT", -540]
+		["1991-04-13T18:00:00+00:00", "03:00:00", "CDT", -540],
+		["1991-09-14T16:59:59+00:00", "01:59:59", "CDT", -540],
+		["1991-09-14T17:00:00+00:00", "01:00:00", "CST", -480]
 	])
 };
\ No newline at end of file
