@@ -182,5 +182,10 @@ exports["Asia/Tbilisi"] = {
 		["2004-06-26T19:00:00+00:00", "23:00:00", "+04", -240],
 		["2004-10-30T22:59:59+00:00", "02:59:59", "+04", -240],
 		["2004-10-30T23:00:00+00:00", "02:00:00", "+03", -180]
+	]),
+
+	"2005" : helpers.makeTestYear("Asia/Tbilisi", [
+		["2005-03-26T22:59:59+00:00", "01:59:59", "+03", -180],
+		["2005-03-26T23:00:00+00:00", "03:00:00", "+04", -240]
 	])
 };
\ No newline at end of file
