@@ -8,6 +8,11 @@ exports["Asia/Yerevan"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Asia/Yerevan", { abbr: true, expect: "Asia/Dubai" }),
 
+	"1924" : helpers.makeTestYear("Asia/Yerevan", [
+		["1924-05-01T21:01:59+00:00", "23:59:59", "LMT", -178],
+		["1924-05-01T21:02:00+00:00", "00:02:00", "+03", -180]
+	]),
+
 	"1957" : helpers.makeTestYear("Asia/Yerevan", [
 		["1957-02-28T20:59:59+00:00", "23:59:59", "+03", -180],
 		["1957-02-28T21:00:00+00:00", "01:00:00", "+04", -240]
@@ -218,6 +223,8 @@ exports["Asia/Yerevan"] = {
 
 	"2011" : helpers.makeTestYear("Asia/Yerevan", [
 		["2011-03-26T21:59:59+00:00", "01:59:59", "+04", -240],
-		["2011-03-26T22:00:00+00:00", "03:00:00", "+05", -300]
+		["2011-03-26T22:00:00+00:00", "03:00:00", "+05", -300],
+		["2011-10-29T21:59:59+00:00", "02:59:59", "+05", -300],
+		["2011-10-29T22:00:00+00:00", "02:00:00", "+04", -240]
 	])
 };
\ No newline at end of file
