@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Atlantic/Azores"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Atlantic/Azores", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Atlantic/Azores", { abbr: true }),
+
 	"1912" : helpers.makeTestYear("Atlantic/Azores", [
 		["1912-01-01T01:59:59+00:00", "00:05:27", "HMT", 6872 / 60],
 		["1912-01-01T02:00:00+00:00", "00:00:00", "-02", 120]
