@@ -83,5 +83,10 @@ exports["Australia/Lindeman"] = {
 		["1993-03-06T16:00:00+00:00", "02:00:00", "AEST", -600],
 		["1993-10-30T15:59:59+00:00", "01:59:59", "AEST", -600],
 		["1993-10-30T16:00:00+00:00", "03:00:00", "AEDT", -660]
+	]),
+
+	"1994" : helpers.makeTestYear("Australia/Lindeman", [
+		["1994-03-05T15:59:59+00:00", "02:59:59", "AEDT", -660],
+		["1994-03-05T16:00:00+00:00", "02:00:00", "AEST", -600]
 	])
 };
\ No newline at end of file
