@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Europe/Dublin"] = {
-	"guess" : helpers.makeTestGuess("Europe/Dublin", { offset: false, abbr: true }),
+
+	"guess:by:offset" : helpers.makeTestGuess("Europe/Dublin", { offset: true, expect: "Europe/London" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Europe/Dublin", { abbr: true }),
 
 	"1916" : helpers.makeTestYear("Europe/Dublin", [
 		["1916-05-21T02:25:20+00:00", "01:59:59", "DMT", 1521 / 60],
