@@ -243,5 +243,10 @@ exports["Europe/Minsk"] = {
 		["2010-03-28T00:00:00+00:00", "03:00:00", "EEST", -180],
 		["2010-10-30T23:59:59+00:00", "02:59:59", "EEST", -180],
 		["2010-10-31T00:00:00+00:00", "02:00:00", "EET", -120]
+	]),
+
+	"2011" : helpers.makeTestYear("Europe/Minsk", [
+		["2011-03-26T23:59:59+00:00", "01:59:59", "EET", -120],
+		["2011-03-27T00:00:00+00:00", "03:00:00", "+03", -180]
 	])
 };
\ No newline at end of file
