@@ -3,6 +3,11 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Europe/Prague"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("Europe/Prague", { offset: true, expect: "Europe/Paris" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Europe/Prague", { abbr: true, expect: "Europe/Paris" }),
+
 	"1916" : helpers.makeTestYear("Europe/Prague", [
 		["1916-04-30T21:59:59+00:00", "22:59:59", "CET", -60],
 		["1916-04-30T22:00:00+00:00", "00:00:00", "CEST", -120],
@@ -44,25 +49,29 @@ exports["Europe/Prague"] = {
 	"1944" : helpers.makeTestYear("Europe/Prague", [
 		["1944-04-03T00:59:59+00:00", "01:59:59", "CET", -60],
 		["1944-04-03T01:00:00+00:00", "03:00:00", "CEST", -120],
-		["1944-09-17T00:59:59+00:00", "02:59:59", "CEST", -120],
-		["1944-09-17T01:00:00+00:00", "02:00:00", "CET", -60]
+		["1944-10-02T00:59:59+00:00", "02:59:59", "CEST", -120],
+		["1944-10-02T01:00:00+00:00", "02:00:00", "CET", -60]
 	]),
 
 	"1945" : helpers.makeTestYear("Europe/Prague", [
-		["1945-04-08T00:59:59+00:00", "01:59:59", "CET", -60],
-		["1945-04-08T01:00:00+00:00", "03:00:00", "CEST", -120],
-		["1945-11-18T00:59:59+00:00", "02:59:59", "CEST", -120],
-		["1945-11-18T01:00:00+00:00", "02:00:00", "CET", -60]
+		["1945-04-02T00:59:59+00:00", "01:59:59", "CET", -60],
+		["1945-04-02T01:00:00+00:00", "03:00:00", "CEST", -120],
+		["1945-10-01T00:59:59+00:00", "02:59:59", "CEST", -120],
+		["1945-10-01T01:00:00+00:00", "02:00:00", "CET", -60]
 	]),
 
 	"1946" : helpers.makeTestYear("Europe/Prague", [
 		["1946-05-06T00:59:59+00:00", "01:59:59", "CET", -60],
 		["1946-05-06T01:00:00+00:00", "03:00:00", "CEST", -120],
 		["1946-10-06T00:59:59+00:00", "02:59:59", "CEST", -120],
-		["1946-10-06T01:00:00+00:00", "02:00:00", "CET", -60]
+		["1946-10-06T01:00:00+00:00", "02:00:00", "CET", -60],
+		["1946-12-01T01:59:59+00:00", "02:59:59", "CET", -60],
+		["1946-12-01T02:00:00+00:00", "02:00:00", "GMT", 0]
 	]),
 
 	"1947" : helpers.makeTestYear("Europe/Prague", [
+		["1947-02-23T01:59:59+00:00", "01:59:59", "GMT", 0],
+		["1947-02-23T02:00:00+00:00", "03:00:00", "CET", -60],
 		["1947-04-20T00:59:59+00:00", "01:59:59", "CET", -60],
 		["1947-04-20T01:00:00+00:00", "03:00:00", "CEST", -120],
 		["1947-10-05T00:59:59+00:00", "02:59:59", "CEST", -120],
