@@ -3,6 +3,11 @@
 var helpers = require("../helpers/helpers");
 
 exports["NZ"] = {
+
+	"guess:by:offset" : helpers.makeTestGuess("NZ", { offset: true, expect: "Pacific/Auckland" }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("NZ", { abbr: true, expect: "Pacific/Auckland" }),
+
 	"1927" : helpers.makeTestYear("NZ", [
 		["1927-11-05T14:29:59+00:00", "01:59:59", "NZMT", -690],
 		["1927-11-05T14:30:00+00:00", "03:00:00", "NZST", -750]
