@@ -3,7 +3,10 @@
 var helpers = require("../../helpers/helpers");
 
 exports["Pacific/Auckland"] = {
-	"guess" : helpers.makeTestGuess("Pacific/Auckland", { offset: true, abbr: true }),
+
+	"guess:by:offset" : helpers.makeTestGuess("Pacific/Auckland", { offset: true }),
+
+	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Auckland", { abbr: true }),
 
 	"1927" : helpers.makeTestYear("Pacific/Auckland", [
 		["1927-11-05T14:29:59+00:00", "01:59:59", "NZMT", -690],
