@@ -25,5 +25,10 @@ exports["Pacific/Honolulu"] = {
 		["1945-08-14T23:00:00+00:00", "13:30:00", "HPT", 570],
 		["1945-09-30T11:29:59+00:00", "01:59:59", "HPT", 570],
 		["1945-09-30T11:30:00+00:00", "01:00:00", "HST", 630]
+	]),
+
+	"1947" : helpers.makeTestYear("Pacific/Honolulu", [
+		["1947-06-08T12:29:59+00:00", "01:59:59", "HST", 630],
+		["1947-06-08T12:30:00+00:00", "02:30:00", "HST", 600]
 	])
 };
\ No newline at end of file
