@@ -31,5 +31,10 @@ exports["Pacific/Majuro"] = {
 	"1944" : helpers.makeTestYear("Pacific/Majuro", [
 		["1944-01-29T14:59:59+00:00", "23:59:59", "+09", -540],
 		["1944-01-29T15:00:00+00:00", "02:00:00", "+11", -660]
+	]),
+
+	"1969" : helpers.makeTestYear("Pacific/Majuro", [
+		["1969-09-30T12:59:59+00:00", "23:59:59", "+11", -660],
+		["1969-09-30T13:00:00+00:00", "01:00:00", "+12", -720]
 	])
 };
\ No newline at end of file
