@@ -8,5 +8,8 @@ exports["Pacific/Pitcairn"] = {
 
 	"guess:by:abbr" : helpers.makeTestGuess("Pacific/Pitcairn", { abbr: true }),
 
-
+	"1998" : helpers.makeTestYear("Pacific/Pitcairn", [
+		["1998-04-27T08:29:59+00:00", "23:59:59", "-0830", 510],
+		["1998-04-27T08:30:00+00:00", "00:30:00", "-08", 480]
+	])
 };
\ No newline at end of file
