@@ -37,6 +37,20 @@ exports["US/Michigan"] = {
 		["1948-09-26T06:00:00+00:00", "01:00:00", "EST", 300]
 	]),
 
+	"1967" : helpers.makeTestYear("US/Michigan", [
+		["1967-06-14T05:00:59+00:00", "00:00:59", "EST", 300],
+		["1967-06-14T05:01:00+00:00", "01:01:00", "EDT", 240],
+		["1967-10-29T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1967-10-29T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
+	"1968" : helpers.makeTestYear("US/Michigan", [
+		["1968-04-28T06:59:59+00:00", "01:59:59", "EST", 300],
+		["1968-04-28T07:00:00+00:00", "03:00:00", "EDT", 240],
+		["1968-10-27T05:59:59+00:00", "01:59:59", "EDT", 240],
+		["1968-10-27T06:00:00+00:00", "01:00:00", "EST", 300]
+	]),
+
 	"1973" : helpers.makeTestYear("US/Michigan", [
 		["1973-04-29T06:59:59+00:00", "01:59:59", "EST", 300],
 		["1973-04-29T07:00:00+00:00", "03:00:00", "EDT", 240],
